/***********************************************************
 * $Id$
 *
 * FancyLibs sane wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSANECALLBACK_H_
#define FANCYSANECALLBACK_H_

#include <fancysane.h>
#include <fancyobject.h>


namespace Fancy {

namespace Drawing {

class Image;
}

namespace Sane {

/**
 * An optional Callback that shows the progress of the scanning and passes the finished image
 */
class FANCYSANE_API SaneCallback : virtual public Fancy::Object
{

public:

    typedef Fancy::ObjPtr<SaneCallback> ptr_t;

    /**
     * A new page is started. It is guaranteed, that either
     * enPage() or pageFaield() is subsequently called.
     */
    virtual void startPage() = 0;

    /**
     * Progress has been made, this callback is called not more than 100 times with
     * values of 1,2,...,100
     */
    virtual void progress(int percentage) = 0;

    /**
     * A page has ended.
     *
     * @image contains the scanned image
     */
    virtual void endPage(const Fancy::ObjPtr<Drawing::Image> &image) = 0;

    /**
     * Scanning a page has failed with an exception.
     *
     */
    virtual void pageFailed(std::exception &e) = 0;

protected:
    SaneCallback();
    virtual ~SaneCallback();
};

}}// end namespaces

#endif
