/***********************************************************
 * $Id$
 *
 * FancyLibs sane wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSANERANGE_H_
#define FANCYSANERANGE_H_

#include <fancysane.h>
#include <fancyserializable.h>

namespace Fancy {

class List;

namespace Sane {

class FANCYSANE_API SaneRange : virtual public Fancy::Serializable
{
    int minimum;
    int maximum;
    int quantity;

public:
    typedef Fancy::ObjPtr<SaneRange> ptr_t;

    static ptr_t newInstance();

    // implementation of Fancy::Serializable
    static Fancy::Serializable::ptr_t newSerializableInstance();
    static int64_t getSerialVersionUID_s();
    static const char *getSerialID_s();
    int64_t getSerialVersionUID() const;
    const char *getSerialID() const;
    void writeFields(const Fancy::ObjPtr<Fancy::Serializer> &serializer) const;
    Fancy::Serializable::ptr_t readFields(const Fancy::ObjPtr<Fancy::Serializer> &serializer, int64_t serialVersionUID);

    int getMaximum() const {
        return this->maximum;
    }

    void setMaximum(int maximum) {
        this->maximum = maximum;
    }

    int getMinimum() const {
        return this->minimum;
    }

    void setMinimum(int minimum) {
        this->minimum = minimum;
    }

    int getQuantity() const {
        return this->quantity;
    }

    void setQuantity(int quantity) {
        this->quantity = quantity;
    }

protected:
    SaneRange();
    virtual ~SaneRange();
};

}}// end namespaces

#endif
